@@ -2,8 +2,6 @@ import math
 
 from pyrf.vrt import I_ONLY
 
-FFT_BASELINE = -10
-
 def compute_fft(dut, data_pkt, context):
     """
     Return an array of dBm values by computing the FFT of
@@ -26,45 +24,47 @@ def compute_fft(dut, data_pkt, context):
 
     iq_data = data_pkt.data.numpy_array()
     # i, q values here are 14-bit signed
-    i_data = numpy.array(iq_data[:,0], dtype=float) / 2**13
-    q_data = numpy.array(iq_data[:,1], dtype=float) / 2**13
+    i_data = numpy.array(iq_data[:,0], dtype=float)
+    q_data = numpy.array(iq_data[:,1], dtype=float)
 
     freq = context['rffreq']
     for low, high, valid_data in dut.CAPTURE_FREQ_RANGES:
         if low <= freq <= high:
             break
-    if valid_data == I_ONLY:
-        return _compute_fft_i_only(i_data, reference_level, dut.ADC_DYNAMIC_RANGE)
-    return _compute_fft(i_data, q_data, reference_level, dut.ADC_DYNAMIC_RANGE)
 
-def _compute_fft(i_data, q_data, reference_level, adc_dynamic_range):
+    if valid_data == I_ONLY:
+        power_spectrum = _compute_fft_i_only(i_data)
+    power_spectrum = _compute_fft(i_data, q_data)
+
+    noiselevel_offset = (
+        reference_level - dut.NOISEFLOOR_CALIBRATION - dut.ADC_DYNAMIC_RANGE)
+    return power_spectrum + noiselevel_offset
+
+
+def _compute_fft(i_data, q_data):
     import numpy
 
     i_removed_dc_offset = i_data - numpy.mean(i_data)
-    q_removed_dc_offset = q_data- numpy.mean(q_data)
+    q_removed_dc_offset = q_data - numpy.mean(q_data)
     calibrated_q = _calibrate_i_q(i_removed_dc_offset, q_removed_dc_offset)
     iq = i_removed_dc_offset + 1j * calibrated_q
     windowed_iq = iq * numpy.hanning(len(i_data))
 
-    noise_level_offset = reference_level - FFT_BASELINE - adc_dynamic_range
+    power_spectrum = numpy.fft.fftshift(numpy.fft.fft(windowed_iq))
+    power_spectrum = 20 * numpy.log10(numpy.abs(power_spectrum)/len(power_spectrum))
 
-    fft_result = numpy.fft.fftshift(numpy.fft.fft(windowed_iq))
-    fft_result = 20 * numpy.log10(numpy.abs(fft_result)) + noise_level_offset
+    median_index = len(power_spectrum) // 2
+    power_spectrum[median_index] = (power_spectrum[median_index - 1]
+        + power_spectrum[median_index + 1]) / 2
+    return power_spectrum
 
-    median_index = len(fft_result) // 2
-    fft_result[median_index] = (fft_result[median_index - 1]
-        + fft_result[median_index + 1]) / 2
-    return fft_result
-
-def _compute_fft_i_only(i_data, reference_level, adc_dynamic_range):
+def _compute_fft_i_only(i_data):
     import numpy
 
     windowed_i = i_data * numpy.hanning(len(i_data))
 
-    noise_level_offset = reference_level - FFT_BASELINE - adc_dynamic_range
-
-    fft_result = numpy.fft.fftshift(numpy.fft.fft(windowed_i))
-    fft_result = 20 * numpy.log10(numpy.abs(fft_result)) + noise_level_offset
+    power_spectrum = numpy.fft.fftshift(numpy.fft.fft(windowed_i))
+    power_spectrum = 20 * numpy.log10(numpy.abs(power_spectrum)/len(power_spectrum))
 
     median_index = len(fft_result) // 2
     return fft_result[median_index+1:]
